@@ -11,23 +11,22 @@ import math
 import os
 import re
 import warnings
-from typing import (Any, Callable, Dict, Iterable, List, Optional, Union)
+from typing import (Any, Callable, Dict, Iterable, List, Optional, Tuple,
+                    Union)
 
 import libsbml as sbml
 import sympy as sp
 
 from . import has_clibs
-from .conserved_moieties import compute_moiety_conservation_laws
 from .constants import SymbolId
-from .import_utils import (CircularDependencyError,
+from .import_utils import (CircularDependencyError, RESERVED_SYMBOLS,
                            _check_unsupported_functions,
                            _get_str_symbol_identifiers,
                            _parse_special_functions,
                            generate_measurement_symbol,
                            noise_distribution_to_cost_function,
                            noise_distribution_to_observable_transformation,
-                           smart_subs, smart_subs_dict, toposort_symbols,
-                           RESERVED_SYMBOLS)
+                           smart_subs, smart_subs_dict, toposort_symbols)
 from .logging import get_logger, log_execution_time, set_log_level
 from .ode_export import (
     ODEExporter, ODEModel, symbol_with_assumptions
@@ -289,7 +288,13 @@ class SbmlImporter:
             Conservation laws for constant species are enabled by default.
             Support for conservation laws for non-constant species is
             experimental and may be enabled by setting an environment variable
-            ``AMICI_EXPERIMENTAL_SBML_NONCONST_CLS`` to any value.
+            ``AMICI_EXPERIMENTAL_SBML_NONCONST_CLS`` to either ``demartino``
+            to use the algorithm proposed by De Martino et al. (2014)
+            https://doi.org/10.1371/journal.pone.0100750, or to any other value
+            to use the deterministic algorithm implemented in
+            ``conserved_moieties2.py``. In some cases, the ``demartino`` may
+            run for a very long time. This has been observed for example in the
+            case of stoichiometric coefficients with many significant digits.
 
         :param simplify:
             see :attr:`ODEModel._simplify`
@@ -1441,22 +1446,22 @@ class SbmlImporter:
         for cl in conservation_laws:
             ode_model.add_conservation_law(**cl)
 
-    def _add_conservation_for_non_constant_species(
-        self,
-        ode_model: ODEModel,
-        conservation_laws: List[ConservationLaw]
-    ) -> List[int]:
-        """Add non-constant species to conservation laws
+    def _get_conservation_laws_demartino(
+            self,
+            ode_model: ODEModel,
+    ) -> List[Tuple[int, List[int], List[float]]]:
+        """Identify conservation laws based on algorithm by DeMartino et al.
+        (see conserved_moieties.py).
 
-        :param ode_model:
-            ODEModel object with basic definitions
-        :param conservation_laws:
-            List of already known conservation laws
-        :returns:
-            List of species indices which later remain in the ODE solver
+        :param ode_model: Model for which to compute conserved quantities
+        :returns: List of one tuple per conservation law, each containing:
+            (0) the index of the (solver-)species to eliminate,
+            (1) (solver-)indices of all species engaged in the conserved
+            quantity (including the eliminated one)
+            (2) coefficients for the species in (1)
         """
-        # indices of retained species
-        species_solver = list(range(ode_model.num_states_rdata()))
+        from .conserved_quantities_demartino \
+            import compute_moiety_conservation_laws
 
         try:
             stoichiometric_list = [
@@ -1470,7 +1475,7 @@ class SbmlImporter:
                           "combination with parameterized stoichiometric "
                           "coefficients are not currently supported "
                           "and will be turned off.")
-            return species_solver
+            return []
 
         if any(rule.getTypeCode() == sbml.SBML_RATE_RULE
                for rule in self.sbml.getListOfRules()):
@@ -1478,7 +1483,7 @@ class SbmlImporter:
             warnings.warn("Conservation laws for non-constant species in "
                           "models with RateRules are not currently supported "
                           "and will be turned off.")
-            return species_solver
+            return []
 
         cls_state_idxs, cls_coefficients = compute_moiety_conservation_laws(
             stoichiometric_list, *self.stoichiometric_matrix.shape,
@@ -1501,7 +1506,105 @@ class SbmlImporter:
             for i, c in zip(cl, coefficients):
                 A[i_cl, i] = sp.Rational(c)
         rref, pivots = A.rref()
-        species_to_be_removed = set(pivots)
+
+        raw_cls = []
+        for i_cl, target_state_model_idx in enumerate(pivots):
+            # collect values for species engaged in the current CL
+            state_idxs = [i for i, coeff in enumerate(rref[i_cl, :])
+                          if coeff]
+            coefficients = [coeff for coeff in rref[i_cl, :] if coeff]
+            raw_cls.append((target_state_model_idx, state_idxs,
+                            coefficients),)
+        return raw_cls
+
+    def _get_conservation_laws_rref(
+            self
+    ) -> List[Tuple[int, List[int], List[float]]]:
+        """Identify conservation laws based on left nullspace of the
+        stoichiometric matrix, computed through (numeric) Gaussian elimination
+
+        :returns: List of one tuple per conservation law, each containing:
+            (0) the index of the (solver-)species to eliminate,
+            (1) (solver-)indices of all species engaged in the conserved
+            quantity (including the eliminated one)
+            (2) coefficients for the species in (1)
+        """
+        import numpy as np
+        from numpy.linalg import matrix_rank
+        from .conserved_quantities_rref import nullspace_by_rref, rref
+
+        try:
+            S = np.asarray(self.stoichiometric_matrix, dtype=float)
+        except TypeError:
+            # Due to the numerical algorithm currently used to identify
+            #  conserved quantities, we can't have symbols in the
+            #  stoichiometric matrix
+            warnings.warn("Conservation laws for non-constant species in "
+                          "combination with parameterized stoichiometric "
+                          "coefficients are not currently supported "
+                          "and will be turned off.")
+            return []
+
+        if any(rule.getTypeCode() == sbml.SBML_RATE_RULE
+               for rule in self.sbml.getListOfRules()):
+            # see SBML semantic test suite, case 33 for an example
+            warnings.warn("Conservation laws for non-constant species in "
+                          "models with RateRules are not currently supported "
+                          "and will be turned off.")
+            return []
+
+        # Determine rank via SVD
+        rank = matrix_rank(S) if S.shape[0] else 0
+        if rank == S.shape[0]:
+            return []
+        kernel = nullspace_by_rref(S.T)
+        # Check dimensions - due to numerical errors, nullspace_by_rref may
+        #  fail in certain situations
+        if kernel.shape[0] != S.shape[0] - rank:
+            raise AssertionError(
+                "Failed to determine all conserved quantities "
+                f"(found {kernel.shape[0]}, expected {S.shape[0] - rank}). "
+                "Try another algorithm, disable detection of conservation "
+                "laws, or submit a bug report along with the model."
+            )
+        kernel = rref(kernel)
+        raw_cls = []
+        for row in kernel:
+            state_idxs = [i for i, coeff in enumerate(row) if coeff]
+            coefficients = [coeff for coeff in row if coeff]
+            print(state_idxs, coefficients)
+            raw_cls.append((state_idxs[0], state_idxs, coefficients),)
+
+        return raw_cls
+
+    def _add_conservation_for_non_constant_species(
+        self,
+        ode_model: ODEModel,
+        conservation_laws: List[ConservationLaw]
+    ) -> List[int]:
+        """Add non-constant species to conservation laws
+
+        :param ode_model:
+            ODEModel object with basic definitions
+        :param conservation_laws:
+            List of already known conservation laws
+        :returns:
+            List of species indices which later remain in the ODE solver
+        """
+        # indices of retained species
+        species_solver = list(range(ode_model.num_states_rdata()))
+
+        algorithm = os.environ.get("AMICI_EXPERIMENTAL_SBML_NONCONST_CLS", "")
+        if algorithm.lower() == "demartino":
+            raw_cls = self._get_conservation_laws_demartino(ode_model)
+        else:
+            raw_cls = self._get_conservation_laws_rref()
+
+        if not raw_cls:
+            # no conservation laws identified
+            return species_solver
+
+        species_to_be_removed = {x[0] for x in raw_cls}
 
         # keep new conservations laws separate until we know everything worked
         new_conservation_laws = []
@@ -1510,22 +1613,20 @@ class SbmlImporter:
 
         all_state_ids = [x.get_id() for x in ode_model._states]
         all_compartment_sizes = [
-            self.compartments[
-                self.symbols[SymbolId.SPECIES][state_id]['compartment']]
-            if not self.symbols[SymbolId.SPECIES][state_id]['amount']
-            else sp.Integer(1)
+            sp.Integer(1)
+            if self.symbols[SymbolId.SPECIES][state_id]['amount']
+            else self.compartments[
+                self.symbols[SymbolId.SPECIES][state_id]['compartment']
+            ]
             for state_id in all_state_ids
         ]
 
         # iterate over list of conservation laws, create symbolic expressions,
-        for i_cl, target_state_model_idx in enumerate(pivots):
+        for target_state_model_idx, state_idxs, coefficients in raw_cls:
             if all_state_ids[target_state_model_idx] in eliminated_state_ids:
                 # constants state, already eliminated
                 continue
             # collect values for species engaged in the current CL
-            state_idxs = [i for i, coeff in enumerate(rref[i_cl, :])
-                          if coeff]
-            coefficients = [coeff for coeff in rref[i_cl, :] if coeff]
             state_ids = [all_state_ids[i_state] for i_state in state_idxs]
             compartment_sizes = [all_compartment_sizes[i] for i in state_idxs]
 
